@@ -2,7 +2,7 @@
 ## R source file
 ## This file is part of rgl
 ##
-## $Id: plugin.R,v 1.1 2003/06/04 07:46:44 dadler Exp $
+## $Id: plugin.R 376 2005-08-03 23:58:47Z dadler $
 ##
 
 ##
@@ -12,7 +12,7 @@
 
 rgl.quit <- function() {
 
-  detach(package:rgl)
+  unloadNamespace("rgl")
 
 }
 
